***************
pysumstats.plot
***************

.. automodule:: pysumstats.plot

Manhattan plot
=========================

.. automethod:: pysumstats.plot.manhattan

QQ plot
=========================

.. automethod:: pysumstats.plot.qqplot

PZ plot
=========================

.. automethod:: pysumstats.plot.pzplot

AF plot
=========================

.. automethod:: pysumstats.plot.afplot

ZZ plot
=========================

.. automethod:: pysumstats.plot.zzplot

